package net.wanji.opt.synthesis.controller;

import io.swagger.annotations.*;
import net.wanji.common.framework.rest.JsonViewObject;
import net.wanji.opt.entity.GreenwaveHist;
import net.wanji.opt.synthesis.pojo.StrategyControlDataEntity;
import net.wanji.opt.synthesis.pojo.StrategyControlDetailList;
import net.wanji.opt.synthesis.pojo.StrategyFactoryEntity;
import net.wanji.opt.synthesis.pojo.vo.StrategyControlVO;
import net.wanji.opt.synthesis.service.StrategyControlService;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.ws.rs.core.MediaType;

/**
 * @author duanruiming
 * @date 2024/11/03 12:42
 * @description 神思电子获取1.1策略计划基础信息
 */
@Api(value = "strategyControl", description = "策略控制")
@RequestMapping("/strategyControl")
@RestController
public class StrategyControlController {

    @Resource
    private StrategyControlService strategyControlService;

    @ApiOperation(value = "策略控制信息操作", notes = "策略控制信息操作",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyInfoOperation",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlVO.class),
    })
    public JsonViewObject strategyInfoOperation(@RequestBody StrategyControlVO strategyControlVO) throws Exception {
        return strategyControlService.strategyInfoOperation(strategyControlVO);
    }

    @ApiOperation(value = "策略控制信息分页查询", notes = "策略控制信息分页查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyInfoPageList",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject strategyInfoPageList(@RequestBody StrategyControlDataEntity entity) throws Exception {
        return strategyControlService.strategyInfoPageList(entity);
    }

    @GetMapping("/crossStrategyHistList")
    @ApiOperation(httpMethod="GET",value="策略执行记录历史->路口/干线，时间粒度, 策略成功失败类型", notes="")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "strategyType", value = "策略类型 0-路口 1-干线 空-查所有", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "groupType", value = "时间粒度类型 0-1小时 1-1天", required = false, dataType = "Integer", defaultValue = "1"),
            @ApiImplicitParam(name = "resultType", value = "时间粒度类型 0-失败 1-成功 空-查所有", required = false, dataType = "Integer"),
    })
    @ApiResponses({
            @ApiResponse(code = 200, message = "成功", response = GreenwaveHist.class,
                    responseHeaders = {@ResponseHeader(name = "Content-Type", description = "application/json")})
    })
    public JsonViewObject crossStrategyHistList(Integer strategyType, Integer groupType, Integer resultType) throws Exception {
        return strategyControlService.crossStrategyHistList(strategyType, groupType, resultType);
    }


    @ApiOperation(value = "策略控制历史查询列表", notes = "策略控制历史查询列表",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/crossStrategyInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject crossStrategyInfoList(@RequestParam Integer type) throws Exception {
        return strategyControlService.crossStrategyInfoList(type);
    }


    @ApiOperation(value = "AI优化次数优化时长", notes = "路网优化检测-AI优化次数优化时长",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/strategyOptTimes")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject strategyOptTimes() throws Exception {
        return strategyControlService.strategyOptTimes();
    }

    @ApiOperation(value = "路网优化监测-路口干线列表", notes = "路网优化监测-AI路口-AI干线",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/crossOptInfoList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDataEntity.class),
    })
    public JsonViewObject crossOptInfoList(@RequestParam Integer type) throws Exception {
        return strategyControlService.crossOptInfoList(type);
    }

    @ApiOperation(value = "策略管理计划详情查询", notes = "策略管理计划详情查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/strategyPlanDetail")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPlanDetail(@RequestParam String crossId) throws Exception {
        return strategyControlService.strategyPlanDetail(crossId);
    }

    @ApiOperation(value = "策略管理计划详情下发", notes = "策略管理计划详情下发",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyPush",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPush(@RequestBody @Validated StrategyControlDetailList list) throws Exception {
        return strategyControlService.strategyPush(list);
    }

    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyPlanSave",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyControlDetailList.class),
    })
    public JsonViewObject strategyPlanSave(@RequestBody @Validated StrategyControlDetailList list) throws Exception {
        return strategyControlService.strategyPlanSave(list);
    }

    @ApiOperation(value = "策略库查询列表", notes = "策略库查询列表",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @GetMapping(value = "/strategyFactoryList")
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactoryList() throws Exception {
        return strategyControlService.strategyFactoryList();
    }

    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyFactorySave",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactorySave(@RequestBody @Validated StrategyFactoryEntity entity) throws Exception {
        return strategyControlService.strategyFactorySave(entity);
    }


    @ApiOperation(value = "策略管理计划保存", notes = "策略管理计划列表查询",
            response = JsonViewObject.class,
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @PostMapping(value = "/strategyFactoryDel",
            produces = MediaType.APPLICATION_JSON, consumes = MediaType.APPLICATION_JSON)
    @ApiResponses({
            @ApiResponse(code = 200, message = "OK", response = StrategyFactoryEntity.class),
    })
    public JsonViewObject strategyFactoryDel(@RequestBody Integer id) throws Exception {
        return strategyControlService.strategyFactoryDel(id);
    }
}
